.. Copyright © SixtyFPS GmbH <info@slint.dev>
.. SPDX-License-Identifier: MIT

Concepts
========

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Concepts

   file.md
   layouting.md
   container.md
   focus.md
   fonts.md
   purity.md
   translations.md
